# jdna

A Python DNA sequence editor that represents sequences as a linked list.
It includes basic molecular reaction simulations (primer annealing, pcr, dna assembly), basic format conversion, and a viewer class.

[Documentation is here](https://jvrana.github.io/jdna/index)

![example.png](./docsrc/_static/viewer.png)
